@@ -39,7 +39,7 @@ class Profile:
         if key.type == KeyType.NONE:
             pass  # do nothing
 
-        elif key.size == "iso":
+        elif key.size in ("iso_h", "iso_v"):
             self.draw_iso_bottom(g, key.bgcol)
             self.draw_iso_top(g, key.bgcol)
 
@@ -55,17 +55,29 @@ class Profile:
     def legend_rect(self, key: Key, size: int) -> Rect:
 
         if size < 4:
-            rect = Rect(*self.text_rect.mod)
+            rect = Rect(*self.text_rect.mod)  # type: ignore  # TODO when we drop 3.6 support
         elif size == 4:
-            rect = Rect(*self.text_rect.symbol)
+            rect = Rect(*self.text_rect.symbol)  # type: ignore  # TODO when we drop 3.6 support
         else:
-            rect = Rect(*self.text_rect.alpha)
+            rect = Rect(*self.text_rect.alpha)  # type: ignore  # TODO when we drop 3.6 support
 
         if key.type == KeyType.NONE:
-            rect = Rect(self.bottom.x, self.bottom.y, self.bottom.w, self.bottom.h)
+            margin = Vector(
+                rect.x - self.top.x,
+                rect.y - self.top.y,
+            )
 
-        if key.size == "iso":
+            rect = Rect(
+                self.bottom.x + margin.x,
+                self.bottom.y + margin.y,
+                self.bottom.w - 2 * margin.x,
+                self.bottom.h - 2 * margin.y,
+            )
+
+        if key.size == "iso_v":
             rect = rect._replace(x=rect.x + 250, w=rect.w + 250, h=rect.h + 1000)
+        elif key.size == "iso_h":
+            rect = rect._replace(w=rect.w + 500)
         elif key.size == "step":
             rect = rect._replace(w=rect.w + 250)
         else:
@@ -77,11 +89,11 @@ class Profile:
 
     def legend_size(self, size: int) -> float:
         if size < 4:
-            return self.text_size.mod * (size / 3)
+            return self.text_size.mod * (size / 3)  # type: ignore  # TODO when we drop 3.6 support
         elif size == 4:
-            return self.text_size.symbol
+            return self.text_size.symbol  # type: ignore  # TODO when we drop 3.6 support
         else:
-            return self.text_size.alpha * (size / 5)
+            return self.text_size.alpha * (size / 5)  # type: ignore # TODO when we drop 3.6 support
 
     def draw_key_bottom(self, g: et.Element, size: Vector, color: Color) -> None:
         rect = self.bottom
@@ -134,17 +146,16 @@ class Profile:
             )
 
         else:
-
+            # curvature of the edges of the key top based on its depth. 0.381 is what "looks right",
+            # there's no other magic behind it
             curve = depth * 0.381
             gradtype = GradientType.SCOOP if keytype == KeyType.SCOOP else GradientType.KEY
 
-            # Calculate the radius of the arc for horizontal and vertical (for spherical) curved
-            # keytop edges using standard formula for segments of an arc using w/h as the widths
-            # and curve as the height
-            hr = (curve ** 2 + (width ** 2 / 4)) / (2 * curve)
-            vr = (curve ** 2 + (height ** 2 / 4)) / (2 * curve)
-
             if keytype == KeyType.SPACE:
+
+                # radius of the curved edges of either side of the top surface of the spacebar
+                vr = (curve ** 2 + (height ** 2 / 4)) / (2 * curve)
+
                 path = (
                     Path()
                     .M(Vector(rect.x, rect.y + rect.r))
@@ -161,6 +172,10 @@ class Profile:
                 gradtype = GradientType.SPACE
 
             elif self.type == ProfileType.CYLINDRICAL:
+
+                # radius of the curved edge at the bottom of the key top rectangle
+                hr = (curve ** 2 + (width ** 2 / 4)) / (2 * curve)
+
                 path = (
                     Path()
                     .M(Vector(rect.x, rect.y + rect.r))
@@ -175,19 +190,61 @@ class Profile:
                 )
 
             else:  # ProfileType.SPHERICAL
+
+                # radius of the curved edges of the key top rectangle
+                width = rect.w - 2 * rect.r
+                height = rect.h - 2 * rect.r
+                hr = (curve ** 2 + (width ** 2 / 4)) / (2 * curve)
+                vr = (curve ** 2 + (height ** 2 / 4)) / (2 * curve)
+
                 path = (
                     Path()
                     .M(Vector(rect.x, rect.y + rect.r))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, -rect.r))
-                    .a(Vector(hr, hr), 0, False, True, Vector(width, 0))
-                    .a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, rect.r))
-                    .a(Vector(vr, vr), 0, False, True, Vector(0, height))
-                    .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, rect.r))
-                    .a(Vector(hr, hr), 0, False, True, Vector(-width, 0))
-                    .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, -rect.r))
-                    .a(Vector(vr, vr), 0, False, True, Vector(0, -height))
-                    .z()
                 )
+                if size.x > 1:
+                    (
+                        path.a(Vector(hr, hr), 0, False, True, Vector(width / 2, -curve))
+                        .h(1000 * (size.x - 1))
+                        .a(Vector(hr, hr), 0, False, True, Vector(width / 2, curve))
+                    )
+                else:
+                    path.a(Vector(hr, hr), 0, False, True, Vector(width, 0))
+
+                path.a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, rect.r))
+
+                if size.y > 1:
+                    (
+                        path.a(Vector(vr, vr), 0, False, True, Vector(curve, height / 2))
+                        .v(1000 * (size.y - 1))
+                        .a(Vector(vr, vr), 0, False, True, Vector(-curve, height / 2))
+                    )
+                else:
+                    path.a(Vector(vr, vr), 0, False, True, Vector(0, height))
+
+                path.a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, rect.r))
+
+                if size.x > 1:
+                    (
+                        path.a(Vector(hr, hr), 0, False, True, Vector(-width / 2, curve))
+                        .h(-1000 * (size.x - 1))
+                        .a(Vector(hr, hr), 0, False, True, Vector(-width / 2, -curve))
+                    )
+                else:
+                    path.a(Vector(hr, hr), 0, False, True, Vector(-width, 0))
+
+                path.a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, -rect.r))
+
+                if size.y > 1:
+                    (
+                        path.a(Vector(vr, vr), 0, False, True, Vector(-curve, -height / 2))
+                        .v(-1000 * (size.y - 1))
+                        .a(Vector(vr, vr), 0, False, True, Vector(curve, -height / 2))
+                    )
+                else:
+                    path.a(Vector(vr, vr), 0, False, True, Vector(0, -height))
+
+                path.z()
 
             et.SubElement(
                 g,
@@ -200,6 +257,40 @@ class Profile:
                 },
             )
 
+        if size == (1, 1):
+            if keytype == KeyType.BAR:
+
+                et.SubElement(
+                    g,
+                    "rect",
+                    {
+                        "fill": color.to_hex(),
+                        "stroke": color.highlight(0.25).to_hex(),
+                        "stroke-width": "10",
+                        "x": _format(500 - self.homing.bar.width / 2),
+                        "y": _format(500 - self.homing.bar.height / 2 + self.homing.bar.offset),
+                        "width": _format(self.homing.bar.width),
+                        "height": _format(self.homing.bar.height),
+                        "rx": _format(self.homing.bar.height / 2),
+                        "ry": _format(self.homing.bar.height / 2),
+                    },
+                )
+
+            elif keytype == KeyType.BUMP:
+
+                et.SubElement(
+                    g,
+                    "circle",
+                    {
+                        "fill": color.to_hex(),
+                        "stroke": color.highlight(0.25).to_hex(),
+                        "stroke-width": "10",
+                        "cx": _format(500),
+                        "cy": _format(500 + self.homing.bump.offset),
+                        "r": _format(self.homing.bump.radius),
+                    },
+                )
+
     def draw_iso_bottom(self, g: et.Element, color: Color) -> None:
         rect = self.bottom
         et.SubElement(
@@ -260,15 +351,11 @@ class Profile:
 
         else:
 
-            # Calculate the radius of the arc for horizontal and vertical (for spherical) curved
-            # keytop edges using standard formula for segments of an arc using w/h as the widths
-            # and curve as the height
-            top_r, btm_r, lefttop_r, leftbtm_r, right_r = (
-                (curve ** 2 + (d ** 2 / 4)) / (2 * curve)
-                for d in (w_top, w_btm, h_lefttop, h_leftbtm, h_right)
-            )
-
             if self.type == ProfileType.CYLINDRICAL:
+
+                # radius of the curved edge at the bottom of the key top rectangle
+                hr = (curve ** 2 + (w_btm ** 2 / 4)) / (2 * curve)
+
                 path = (
                     Path()
                     .M(Vector(rect.x, rect.y + rect.r))
@@ -277,7 +364,7 @@ class Profile:
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, rect.r))
                     .v(h_right)
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, rect.r))
-                    .a(Vector(btm_r, btm_r), 0, False, True, Vector(-w_btm, 0))
+                    .a(Vector(hr, hr), 0, False, True, Vector(-w_btm, 0))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, -rect.r))
                     .v(-(h_leftbtm))
                     .a(Vector(rect.r, rect.r), 0, False, False, Vector(-rect.r, -rect.r))
@@ -288,21 +375,37 @@ class Profile:
                 )
 
             else:  # ProfileType.SPHERICAL
+
+                # radius of the curved edges of the key top rectangle
+                width = rect.w - 2 * rect.r
+                height = rect.h - 2 * rect.r
+                hr = (curve ** 2 + (width ** 2 / 4)) / (2 * curve)
+                vr = (curve ** 2 + (height ** 2 / 4)) / (2 * curve)
+
+                h_leftbtm = 1000 - curve / 2 - 2 * rect.r
+
                 path = (
                     Path()
                     .M(Vector(rect.x, rect.y + rect.r))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, -rect.r))
-                    .a(Vector(top_r, top_r), 0, False, True, Vector(w_top, 0))
+                    .a(Vector(hr, hr), 0, False, True, Vector(width / 2, -curve))
+                    .h(500)
+                    .a(Vector(hr, hr), 0, False, True, Vector(width / 2, curve))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(rect.r, rect.r))
-                    .a(Vector(right_r, right_r), 0, False, True, Vector(0, h_right))
+                    .a(Vector(vr, vr), 0, False, True, Vector(curve, height / 2))
+                    .v(1000)
+                    .a(Vector(vr, vr), 0, False, True, Vector(-curve, height / 2))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, rect.r))
-                    .a(Vector(btm_r, btm_r), 0, False, True, Vector(-w_btm, 0))
+                    .a(Vector(hr, hr), 0, False, True, Vector(-width / 2, curve))
+                    .h(-250)
+                    .a(Vector(hr, hr), 0, False, True, Vector(-width / 2, -curve))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, -rect.r))
-                    .a(Vector(leftbtm_r, leftbtm_r), 0, False, True, Vector(0, -h_leftbtm))
+                    .a(Vector(vr, vr), 0, False, True, Vector(-curve, -height / 2))
+                    .v(-(h_leftbtm - height / 2))
                     .a(Vector(rect.r, rect.r), 0, False, False, Vector(-rect.r, -rect.r))
-                    .l(Vector(-(250 - 2 * rect.r), -curve / 3))
+                    .l(Vector(-(250 - 2 * rect.r - curve), -curve / 2))
                     .a(Vector(rect.r, rect.r), 0, False, True, Vector(-rect.r, -rect.r))
-                    .a(Vector(lefttop_r, lefttop_r), 0, False, True, Vector(0, -h_lefttop))
+                    .a(Vector(vr, vr), 0, False, True, Vector(0, -h_lefttop))
                     .z()
                 )
 
